summaryrefslogtreecommitdiff
path: root/source3/rpc_client
diff options
context:
space:
mode:
authorLuke Leighton <lkcl@samba.org>1998-11-11 00:43:41 +0000
committerLuke Leighton <lkcl@samba.org>1998-11-11 00:43:41 +0000
commitedf630c85ea6a1d4bfa74427190e27c3a97085ea (patch)
tree6b49d8a4c0342ebd5716711c1c06d01759796c6a /source3/rpc_client
parentd90f25d38098de5e41e745e801a8dcbab727c285 (diff)
downloadsamba-edf630c85ea6a1d4bfa74427190e27c3a97085ea.tar.gz
samba-edf630c85ea6a1d4bfa74427190e27c3a97085ea.tar.bz2
samba-edf630c85ea6a1d4bfa74427190e27c3a97085ea.zip
renamed unk_1b to flush_key
(This used to be commit ddfdb6534671a0e9bbbefe555a92925d41abaddf)
Diffstat (limited to 'source3/rpc_client')
-rw-r--r--source3/rpc_client/cli_reg.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/source3/rpc_client/cli_reg.c b/source3/rpc_client/cli_reg.c
index a38be4149d..e1872bbd79 100644
--- a/source3/rpc_client/cli_reg.c
+++ b/source3/rpc_client/cli_reg.c
@@ -208,11 +208,11 @@ do a REG Unknown 0xB command. sent after a create key or create value.
this might be some sort of "sync" or "refresh" command, sent after
modification of the registry...
****************************************************************************/
-BOOL do_reg_unk_b(struct cli_state *cli, POLICY_HND *hnd)
+BOOL do_reg_flush_key(struct cli_state *cli, POLICY_HND *hnd)
{
prs_struct rbuf;
prs_struct buf;
- REG_Q_UNK_B q_o;
+ REG_Q_FLUSH_KEY q_o;
BOOL valid_query = False;
if (hnd == NULL) return False;
@@ -220,30 +220,30 @@ BOOL do_reg_unk_b(struct cli_state *cli, POLICY_HND *hnd)
prs_init(&buf , 1024, 4, SAFETY_MARGIN, False);
prs_init(&rbuf, 0 , 4, SAFETY_MARGIN, True );
/* create and send a MSRPC command with api REG_UNK_B */
DEBUG(4,("REG Unknown 0xB\n"));
- make_reg_q_unk_b(&q_o, hnd);
+ make_reg_q_flush_key(&q_o, hnd);
/* turn parameters into data stream */
- reg_io_q_unk_b("", &q_o, &buf, 0);
+ reg_io_q_flush_key("", &q_o, &buf, 0);
/* send the data on \PIPE\ */
- if (rpc_api_pipe_req(cli, REG_UNK_B, &buf, &rbuf))
+ if (rpc_api_pipe_req(cli, REG_FLUSH_KEY, &buf, &rbuf))
{
- REG_R_UNK_B r_o;
+ REG_R_FLUSH_KEY r_o;
BOOL p;
ZERO_STRUCT(r_o);
- reg_io_r_unk_b("", &r_o, &rbuf, 0);
+ reg_io_r_flush_key("", &r_o, &rbuf, 0);
p = rbuf.offset != 0;
if (p && r_o.status != 0)
{
/* report error code */
- DEBUG(0,("REG_UNK_B: %s\n", get_nt_error_msg(r_o.status)));
+ DEBUG(0,("REG_FLUSH_KEY: %s\n", get_nt_error_msg(r_o.status)));
p = False;
}
@@ -220,30 +220,30 @@ BOOL do_reg_unk_b(struct cli_state *cli, POLICY_HND *hnd)
prs_init(&buf , 1024, 4, SAFETY_MARGIN, False);
prs_init(&rbuf, 0 , 4, SAFETY_MARGIN, True );
- /* create and send a MSRPC command with api REG_UNK_B */
+ /* create and send a MSRPC command with api REG_FLUSH_KEY */
DEBUG(4,("REG Unknown 0xB\n"));